@@ -1,20 +1,18 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2008 by Enthought, Inc.
+# Copyright (c) 2008-2009 by Enthought, Inc.
 # All rights reserved.
-#
 
-from distutils import log
-from distutils.command.clean import clean
-from distutils.errors import DistutilsSetupError
-from pkg_resources import DistributionNotFound, parse_version, require, \
-    VersionConflict
-from setuptools import Command, Extension,  find_packages, setup
-from setuptools.command.bdist_egg import bdist_egg
 import os, sys
 import shutil
 import subprocess
 import zipfile
+from distutils import log
+from distutils.command.clean import clean
+from distutils.errors import DistutilsSetupError
+
+from setuptools import Command
+
 
 DOC_DIR = os.path.join(os.path.abspath(os.getcwd()), 'docs')
 SOURCE_DIR = os.path.join(DOC_DIR, 'source')
@@ -24,29 +22,20 @@ BUILD_DIR = os.path.join(os.path.abspath(os.getcwd()), 'build')
 TARGET_DIR = os.path.join(BUILD_DIR, 'docs')
 
 def is_sphinx_installed():
-    """Check to see if Sphinx is installed both by setuptools require and simple
-    import. Return True or False based on results.
+    """
+    Check to see if Sphinx is installed (based on a simple import).
     """
     required_sphinx_version = "0.4.2"
-    sphinx_installed = False
     try:
-        require("Sphinx>=%s" % required_sphinx_version)
-        sphinx_installed = True
-    except (DistributionNotFound, VersionConflict):
-        log.warn('Sphinx install of version >=%s could not be verified.'
-            ' Trying simple import...' % required_sphinx_version)
-        try:
-            import sphinx
-            if parse_version(sphinx.__version__) < parse_version(
-                required_sphinx_version):
-                log.error("Sphinx version must be >=" +\
-                    "%s." % required_sphinx_version)
-            else:
-                sphinx_installed = True
-        except ImportError:
-            log.error("Sphinx install not found.")
+        import sphinx
+        # FIXME: Once verlib is in the stdlib, use verlib's comparison
+        if sphinx.__version__ < "required_sphinx_version":
+            log.warn('Sphinx install of version >=%s could not be verified.'
+                     % required_sphinx_version)
+        return True
+    except ImportError:
+        return False
 
-    return sphinx_installed
 
 def create_html_zip(target, commit):
     """Create html_docs.zip in target directory. This is useful if the rst
